@@ -1,5 +1,3 @@
-from __future__ import unicode_literals, print_function
-
 import logging
 from flask import request, url_for, redirect, current_app
 from werkzeug.wrappers import Response
@@ -31,6 +29,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         import_name,
         client_key=None,
         client_secret=None,
+        *,
         signature_method=SIGNATURE_HMAC,
         signature_type=SIGNATURE_TYPE_AUTH_HEADER,
         rsa_key=None,
@@ -53,6 +52,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         redirect_to=None,
         session_class=None,
         storage=None,
+        rule_kwargs=None,
         **kwargs
     ):
         """
@@ -108,6 +108,8 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             storage: A token storage class, or an instance of a token storage
                 class, to use for this blueprint. Defaults to
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
+            rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+                the login and authorized routes. Defaults to ``None``.
         """
         BaseOAuthConsumerBlueprint.__init__(
             self,
@@ -123,6 +125,7 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             login_url=login_url,
             authorized_url=authorized_url,
             storage=storage,
+            rule_kwargs=rule_kwargs,
         )
 
         self.base_url = base_url
@@ -169,7 +172,10 @@ class OAuth1ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         )
 
     def teardown_session(self, exception=None):
-        invalidate_cached_property(self, "session")
+        try:
+            invalidate_cached_property(self, "session")
+        except KeyError:
+            pass
 
     def login(self):
         callback_uri = url_for(".authorized", _external=True)
