@@ -1,4 +1,3 @@
-from __future__ import unicode_literals, print_function
 import json
 
 import logging
@@ -31,6 +30,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         import_name,
         client_id=None,
         client_secret=None,
+        *,
         client=None,
         auto_refresh_url=None,
         auto_refresh_kwargs=None,
@@ -54,7 +54,8 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         redirect_to=None,
         session_class=None,
         storage=None,
-        **kwargs
+        rule_kwargs=None,
+        **kwargs,
     ):
         """
         Most of the constructor arguments are forwarded either to the
@@ -112,6 +113,8 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             storage: A token storage class, or an instance of a token storage
                 class, to use for this blueprint. Defaults to
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
+            rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+                the login and authorized routes. Defaults to ``None``.
         """
         BaseOAuthConsumerBlueprint.__init__(
             self,
@@ -127,6 +130,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             login_url=login_url,
             authorized_url=authorized_url,
             storage=storage,
+            rule_kwargs=rule_kwargs,
         )
 
         self.base_url = base_url
@@ -179,7 +183,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             state=self.state,
             blueprint=self,
             base_url=self.base_url,
-            **self.kwargs
+            **self.kwargs,
         )
 
         def token_updater(token):
@@ -192,7 +196,10 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         return session
 
     def teardown_session(self, exception=None):
-        invalidate_cached_property(self, "session")
+        try:
+            invalidate_cached_property(self, "session")
+        except KeyError:
+            pass
 
     def login(self):
         log.debug("client_id = %s", self.client_id)
@@ -200,7 +207,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         url, state = self.session.authorization_url(
             self.authorization_url, state=self.state, **self.authorization_url_params
         )
-        state_key = "{bp.name}_oauth_state".format(bp=self)
+        state_key = f"{self.name}_oauth_state"
         flask.session[state_key] = state
         log.debug("state = %s", state)
         log.debug("redirect URL = %s", url)
@@ -237,7 +244,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             )
             return redirect(next_url)
 
-        state_key = "{bp.name}_oauth_state".format(bp=self)
+        state_key = f"{self.name}_oauth_state"
         if state_key not in flask.session:
             # can't validate state, so redirect back to login view
             log.info("state not found, redirecting user to login")
@@ -257,7 +264,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
                 self.token_url,
                 authorization_response=request.url,
                 client_secret=self.client_secret,
-                **self.token_url_params
+                **self.token_url_params,
             )
         except MissingCodeError as e:
             e.args = (
