@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
-
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 
 __maintainer__ = "Steven MARTINS <steven.martins.fr@gmail.com>"
@@ -16,6 +11,7 @@ __maintainer__ = "Steven MARTINS <steven.martins.fr@gmail.com>"
 def make_azure_blueprint(
     client_id=None,
     client_secret=None,
+    *,
     scope=None,
     redirect_url=None,
     redirect_to=None,
@@ -27,6 +23,7 @@ def make_azure_blueprint(
     prompt=None,
     domain_hint=None,
     login_hint=None,
+    rule_kwargs=None,
 ):
     """
     Make a blueprint for authenticating with Azure AD using OAuth 2. This requires
@@ -74,10 +71,11 @@ def make_azure_blueprint(
             having already extracted the username from a previous sign-in using the
             preferred_username claim.
             Defaults to ``None``
-
+        rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+            the login and authorized routes. Defaults to ``None``.
 
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     scope = scope or ["openid", "email", "profile", "User.Read"]
     authorization_url_params = {}
@@ -94,12 +92,8 @@ def make_azure_blueprint(
         client_secret=client_secret,
         scope=scope,
         base_url="https://graph.microsoft.com",
-        authorization_url="https://login.microsoftonline.com/{tenant}/oauth2/v2.0/authorize".format(
-            tenant=tenant
-        ),
-        token_url="https://login.microsoftonline.com/{tenant}/oauth2/v2.0/token".format(
-            tenant=tenant
-        ),
+        authorization_url=f"https://login.microsoftonline.com/{tenant}/oauth2/v2.0/authorize",
+        token_url=f"https://login.microsoftonline.com/{tenant}/oauth2/v2.0/token",
         redirect_url=redirect_url,
         redirect_to=redirect_to,
         login_url=login_url,
@@ -107,6 +101,7 @@ def make_azure_blueprint(
         authorization_url_params=authorization_url_params,
         session_class=session_class,
         storage=storage,
+        rule_kwargs=rule_kwargs,
     )
     azure_bp.from_config["client_id"] = "AZURE_OAUTH_CLIENT_ID"
     azure_bp.from_config["client_secret"] = "AZURE_OAUTH_CLIENT_SECRET"
