@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
-
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 
 __maintainer__ = "Przemyslaw Kanach <kanach16@gmail.com>"
@@ -16,6 +11,7 @@ __maintainer__ = "Przemyslaw Kanach <kanach16@gmail.com>"
 def make_salesforce_blueprint(
     client_id=None,
     client_secret=None,
+    *,
     scope=None,
     reprompt_consent=False,
     hostname=None,
@@ -63,7 +59,7 @@ def make_salesforce_blueprint(
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
 
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     authorization_url_params = {}
     if reprompt_consent:
@@ -78,11 +74,9 @@ def make_salesforce_blueprint(
         client_id=client_id,
         client_secret=client_secret,
         scope=scope,
-        base_url="https://{hostname}/".format(hostname=hostname),
-        authorization_url=(
-            "https://{hostname}/services/oauth2/authorize".format(hostname=hostname)
-        ),
-        token_url="https://{hostname}/services/oauth2/token".format(hostname=hostname),
+        base_url=f"https://{hostname}/",
+        authorization_url=f"https://{hostname}/services/oauth2/authorize",
+        token_url=f"https://{hostname}/services/oauth2/token",
         redirect_url=redirect_url,
         redirect_to=redirect_to,
         login_url=login_url,
