@@ -1,14 +1,9 @@
-from __future__ import unicode_literals
-
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from requests_oauthlib.compliance_fixes.slack import slack_compliance_fix
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 
 __maintainer__ = "David Baumgold <david@davidbaumgold.com>"
@@ -22,6 +17,7 @@ class SlackBlueprint(OAuth2ConsumerBlueprint):
 def make_slack_blueprint(
     client_id=None,
     client_secret=None,
+    *,
     scope=None,
     redirect_url=None,
     redirect_to=None,
@@ -30,6 +26,7 @@ def make_slack_blueprint(
     session_class=None,
     storage=None,
     subdomain=None,
+    rule_kwargs=None,
 ):
     """
     Make a blueprint for authenticating with Slack using OAuth 2. This requires
@@ -59,9 +56,11 @@ def make_slack_blueprint(
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
         subdomain (str, optional): the name of the subdomain under which your
             Slack space is accessed. Providing this may improve the login experience.
+        rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+            the login and authorized routes. Defaults to ``None``.
 
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     scope = scope or ["identify", "chat:write:bot"]
     slack_bp = SlackBlueprint(
@@ -73,9 +72,7 @@ def make_slack_blueprint(
         base_url="https://slack.com/api/",
         authorization_url="https://slack.com/oauth/authorize"
         if subdomain is None
-        else "https://{subdomain}.slack.com/oauth/authorize".format(
-            subdomain=subdomain
-        ),
+        else f"https://{subdomain}.slack.com/oauth/authorize",
         token_url="https://slack.com/api/oauth.access",
         redirect_url=redirect_url,
         redirect_to=redirect_to,
@@ -83,6 +80,7 @@ def make_slack_blueprint(
         authorized_url=authorized_url,
         session_class=session_class,
         storage=storage,
+        rule_kwargs=rule_kwargs,
     )
     slack_bp.from_config["client_id"] = "SLACK_OAUTH_CLIENT_ID"
     slack_bp.from_config["client_secret"] = "SLACK_OAUTH_CLIENT_SECRET"
