@@ -1,14 +1,10 @@
-from __future__ import unicode_literals
 from oauthlib.oauth2.rfc6749 import tokens
 from oauthlib.oauth2.rfc6749.clients.web_application import WebApplicationClient
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 __maintainer__ = "Ryan Schaffer <schaffer.ry@gmail.com>"
 
@@ -21,6 +17,7 @@ ZOHO_TOKEN_HEADER = "Zoho-oauthtoken"
 def make_zoho_blueprint(
     client_id=None,
     client_secret=None,
+    *,
     scope=None,
     redirect_url=None,
     offline=False,
@@ -29,6 +26,7 @@ def make_zoho_blueprint(
     session_class=None,
     storage=None,
     reprompt_consent=False,
+    rule_kwargs=None,
 ):
     """
     Make a blueprint for authenticating with Zoho using OAuth 2. This requires
@@ -61,9 +59,12 @@ def make_zoho_blueprint(
             for the OAuth token. Defaults to False
         reprompt_consent (bool): If True, force Zoho to re-prompt the user
             for their consent, even if the user has already given their
-            consent. Defaults to False
+            consent. Defaults to False.
+        rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+            the login and authorized routes. Defaults to ``None``.
+
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     scope = scope or ["ZohoCRM.users.all"]
     base_url = "https://www.zohoapis.com/"
@@ -88,6 +89,7 @@ def make_zoho_blueprint(
         login_url=login_url,
         session_class=session_class,
         storage=storage,
+        rule_kwargs=rule_kwargs,
     )
 
     zoho_bp.from_config["client_id"] = "ZOHO_OAUTH_CLIENT_ID"
